#!/bin/sh
export PATH='/usr/obj/ports/hs-async-2.1.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: async
version: 2.1.0
id: async-2.1.0-39dbaa8053baa5d86bb55ba090d6bf66
key: async_5jwpzKVjQQAElehhWvNUXP
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
trusted: False
import-dirs: /usr/local/lib/ghc/async-2.1.0
library-dirs: /usr/local/lib/ghc/async-2.1.0
data-dir: /usr/local/share/hs-async-2.1.0
hs-libraries: HSasync-2.1.0-5jwpzKVjQQAElehhWvNUXP
depends:
    base-4.8.2.0-8dd7859ce039df9f3d3f4ff9dbf4bb93
    stm-2.4.4-e969ad03f1a61caf3d689ab8ef7862f8
haddock-interfaces: /usr/local/share/doc/hs-async-2.1.0/html/async.haddock
haddock-html: /usr/local/share/doc/hs-async-2.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
